@@ -1,7 +1,7 @@
 /*
  * block - fixed, dynamic, fifo and circular memory blocks
  *
- * Copyright (C) 1999-2007,2014  Landon Curt Noll and Ernest Bowen
+ * Copyright (C) 1999-2007,2014,2021  Landon Curt Noll and Ernest Bowen
  *
  * Primary author:  Landon Curt Noll
  *
@@ -19,10 +19,6 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.3 $
- * @(#) $Id: block.h,v 30.3 2014/08/24 21:56:51 chongo Exp $
- * @(#) $Source: /usr/local/src/bin/calc/RCS/block.h,v $
- *
  * Under source code control:	1997/02/21 05:03:39
  * File existed as early as:	1997
  *
@@ -59,7 +55,7 @@
  *		blkchunk defaults to BLK_CHUNKSIZE
  *
  *	blkfree(x)
- *		Reduce storage down to 0 octetes.
+ *		Reduce storage down to 0 octets.
  *
  *	size(x)
  *		The length of data stored in the block.
@@ -92,7 +88,7 @@
  *	blkmove(dest, src, length [, dest_offset [, src_offset]])
  *		0 <= length <= blksize(x)
  *		offset's are restricted in value by block type
- *		overlapping moves are handeled correctly
+ *		overlapping moves are handled correctly
  *
  *	blkccpy(dest, src, stopval, length [, dest_offset [, src_offset]])
  *		0 <= length <= blksize(x)
@@ -108,7 +104,7 @@
  *		b = a*k for some integer k >= 1
  *
  *	scatter(src, dest1, dest2 [, dest3 ] ...)
- *		copy sucessive octets from src into dest1, dest2, ...
+ *		copy successive octets from src into dest1, dest2, ...
  *		    restarting with dest1 after end of list
  *		stops at end of src
  *
@@ -188,7 +184,7 @@ EXTERN int blk_debug;	/* 0 => debug off */
 /* length of data stored in a block */
 #define blklen(blk) ((blk)->datalen)
 
-/* block footpint in memory */
+/* block footprint in memory */
 #define blksizeof(blk) ((blk)->maxsize)
 
 /* block allocation chunk size */
